@@ -14,7 +14,7 @@ use Archive::Extract ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.29';
+	$VERSION = '0.30';
 }
 
 
@@ -52,10 +52,6 @@ sub extract_files {
 	$files ? @$files : ();
 }
 
-sub platform {
-	$_[0]->{platform};
-}
-
 
 
 
